@@ -30,7 +30,8 @@ func isEnum(ts *ast.TypeSpec) bool {
 	}
 
 	if id, ok := ts.Type.(*ast.Ident); ok {
-		if id.Name == "string" || id.Name == "int64" {
+		switch id.Name {
+		case "string", "int", "int32", "int64", "uint32", "uint64", "float64", "bool":
 			return true
 		}
 	}
@@ -56,9 +57,11 @@ func parseTag(line string) (tag string, value string) {
 			if line[i] == ' ' {
 				tag = line[1:i]
 				value = line[i+1:]
-				break
+				return
 			}
 		}
+		// No space found — tag with no value (e.g. "@deprecated")
+		tag = line[1:]
 	}
 	return
 }
