@@ -24,10 +24,10 @@ async function main() {
     $(`gitbook build`);
   });
 
-  if (process.env.CI_COMMIT_REF_NAME) {
-    $(`gsutil -m cp -r -a public-read docs/_book/* gs://docs.itch.zone/butler/${process.env.CI_COMMIT_REF_NAME}/`);
+  if (process.env.GITHUB_REF_NAME) {
+    $(`gsutil -m cp -r -a public-read docs/_book/* gs://docs.itch.zone/butler/${process.env.GITHUB_REF_NAME}/`);
   } else {
-    console.warn("Skipping uploading book, no CI_COMMIT_REF_NAME environment variable set")
+    console.warn("Skipping uploading book, no GITHUB_REF_NAME environment variable set")
   }
 }
 
